@@ -501,7 +501,10 @@ class ParametersLEDET:
         return k.shape[0]
 
     def checkM_InductanceBlock_m(self, Turns):
-        k = self.Inputs.M_InductanceBlock_m
+        if type(self.Inputs.M_InductanceBlock_m) != np.ndarray:
+            k = np.array(self.Inputs.M_InductanceBlock_m)
+        else:
+            k = self.Inputs.M_InductanceBlock_m
         if k.shape == (1,):
             return False
         try:
@@ -597,7 +600,7 @@ class ParametersLEDET:
                 if not len(cC)==sizeInputs[Count]:
                     print("The variable ",k, " does not have the correct size, should be", sizeInputs[Count]," but is ",len(cC),"! Please check.")
                     Break = 1
-            elif type(cC) == float or type(cC) == int:
+            elif type(cC) == float or type(cC) == int or type(cC) == np.float64:
                 if not sizeInputs[Count]==1:
                     print("The variable ", k, " does not have the correct size, should be", sizeInputs[Count]," but is ",len(cC)," Please check.")
                     Break = 1
@@ -699,6 +702,14 @@ class ParametersLEDET:
         for attribute in variableGroup.__annotations__:
             if (attribute == "BlankRows"):
                 continue
+            if (attribute == "overwrite_f_internalVoids_inGroup"):
+                ofiVg = self.getAttribute(variableGroup, attribute)
+                if len(ofiVg) == 0:
+                    continue
+            if (attribute == "overwrite_f_externalVoids_inGroup"):
+                ofiVg = self.getAttribute(variableGroup, attribute)
+                if len(ofiVg) == 0:
+                    continue
             if currentRow in variableGroup.BlankRows[1]:
                 currentRow = currentRow + 1
             varDesc = variableLabels.get(str(attribute))
