@@ -130,7 +130,7 @@ def EvaluateSimulations(MatFolder, MagnetName, MeasFile, SweepObject, Mat = True
         dImeas[abs(dImeas) < SetdITol] = 0
         tshift_Sim = SimData[0, 1:][np.nonzero(dImeas)[0][0]]
         tshift = tshift - tshift_Sim
-        idx_low = np.argmin(abs(Tmeas - tshift - Time_Zone[0]))+1
+        idx_low = np.argmin(abs(Tmeas - tshift - Time_Zone[0]))
     else:
         idx_low = 0
         idx_up = -1
@@ -264,13 +264,13 @@ def EvaluateSimulations(MatFolder, MagnetName, MeasFile, SweepObject, Mat = True
         LengthStep = int(TotLength/len(BestFit))
         ax.plot(SimData[0, 1:].astype(float), SimData[BestFit[0]+1, 1:].astype(float), color=colors(2*opacity),
                 alpha=opacity, label='_nolegend_')
-        ax.text(SimData[0, TotLength].astype(float),SimData[BestFit[0]+1, TotLength].astype(float), str(0), alpha = opacity)
+        # ax.text(SimData[0, TotLength].astype(float),SimData[BestFit[0]+1, TotLength].astype(float), str(0), alpha = opacity)
         for i in range(1,len(BestFit)):
             opacity = (opacity - dec)
             ax.plot(SimData[0, 1:].astype(float), SimData[BestFit[i]+1, 1:].astype(float), color=colors(2*opacity),
                     alpha=opacity, label='_nolegend_')
-            ax.text(SimData[0, TotLength+i*LengthStep].astype(float), SimData[BestFit[i]+1, TotLength+i*LengthStep].astype(float), str(i),
-                    alpha=opacity)
+            # ax.text(SimData[0, TotLength+i*LengthStep].astype(float), SimData[BestFit[i]+1, TotLength+i*LengthStep].astype(float), str(i),
+            #         alpha=opacity)
         sm = plt.cm.ScalarMappable(cmap=colors)
         cbar = plt.colorbar(sm)
         cbar.set_ticks([1])
@@ -309,7 +309,7 @@ def EvaluateSimulations(MatFolder, MagnetName, MeasFile, SweepObject, Mat = True
         ax.set_ylim3d(0, 4)
         ax.set_zlabel('Inverse MSE', fontsize = 14,labelpad=10)
         ax.set_zlim3d(0, 1/MSESims[BestFit[0], 1])
-        plt.yticks(zs, ParametersToSweep)
+        plt.yticks(zs, ParametersToSweep, fontsize =14)
         plt.plot([xb/np.max(SweepMatrix[:,0])],[1.], 1/MSESims[BestFit[0], 1], markerfacecolor='k', markeredgecolor='k', marker='o', markersize=4, alpha=0.6, label="Best fit")
         plt.plot([yb/np.max(SweepMatrix[:,1])], [2.], 1/MSESims[BestFit[0], 1], markerfacecolor='k', markeredgecolor='k', marker='o', markersize=4,
                  alpha=0.6)
@@ -320,7 +320,7 @@ def EvaluateSimulations(MatFolder, MagnetName, MeasFile, SweepObject, Mat = True
         plt.plot([xb / np.max(SweepMatrix[:, 0]),xb / np.max(SweepMatrix[:, 0])], [1.,1.], [0.,1/MSESims[BestFit[0], 1]],'--',color='r')
         plt.plot([yb / np.max(SweepMatrix[:, 1]),yb / np.max(SweepMatrix[:, 1])], [2.,2.], [0.,1/MSESims[BestFit[0], 1]],'--',color='g')
         plt.plot([kb / np.max(SweepMatrix[:, 2]),kb / np.max(SweepMatrix[:, 2])], [3.,3.], [0.,1/MSESims[BestFit[0], 1]],'--',color='y')
-        plt.legend()
+        plt.legend(fontsize =14)
         plt.show()
 
         ##Plot 3
